# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RuleEnforcementArgs', 'RuleEnforcement']

@pulumi.input_type
class RuleEnforcementArgs:
    def __init__(__self__, *,
                 cloud_provider: pulumi.Input[_builtins.str],
                 execution_schedule: pulumi.Input[_builtins.str],
                 execution_timezone: pulumi.Input[_builtins.str],
                 target_accounts: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rule_set_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_regions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a RuleEnforcement resource.
        :param pulumi.Input[_builtins.str] cloud_provider: The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        :param pulumi.Input[_builtins.str] execution_schedule: Execution schedule in cron format.
        :param pulumi.Input[_builtins.str] execution_timezone: Timezone for the execution schedule.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_accounts: List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        :param pulumi.Input[_builtins.str] description: Description for rule enforcement.
        :param pulumi.Input[_builtins.bool] is_dry_run: Indicates if the rule enforcement is a dry run. This by default is set to false.
        :param pulumi.Input[_builtins.bool] is_enabled: Indicates if the rule enforcement is enabled. This by default is set to true.
        :param pulumi.Input[_builtins.str] name: Name of the rule enforcement.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_ids: List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_set_ids: List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_regions: List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        pulumi.set(__self__, "cloud_provider", cloud_provider)
        pulumi.set(__self__, "execution_schedule", execution_schedule)
        pulumi.set(__self__, "execution_timezone", execution_timezone)
        pulumi.set(__self__, "target_accounts", target_accounts)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_dry_run is not None:
            pulumi.set(__self__, "is_dry_run", is_dry_run)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rule_ids is not None:
            pulumi.set(__self__, "rule_ids", rule_ids)
        if rule_set_ids is not None:
            pulumi.set(__self__, "rule_set_ids", rule_set_ids)
        if target_regions is not None:
            pulumi.set(__self__, "target_regions", target_regions)

    @_builtins.property
    @pulumi.getter(name="cloudProvider")
    def cloud_provider(self) -> pulumi.Input[_builtins.str]:
        """
        The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        """
        return pulumi.get(self, "cloud_provider")

    @cloud_provider.setter
    def cloud_provider(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud_provider", value)

    @_builtins.property
    @pulumi.getter(name="executionSchedule")
    def execution_schedule(self) -> pulumi.Input[_builtins.str]:
        """
        Execution schedule in cron format.
        """
        return pulumi.get(self, "execution_schedule")

    @execution_schedule.setter
    def execution_schedule(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "execution_schedule", value)

    @_builtins.property
    @pulumi.getter(name="executionTimezone")
    def execution_timezone(self) -> pulumi.Input[_builtins.str]:
        """
        Timezone for the execution schedule.
        """
        return pulumi.get(self, "execution_timezone")

    @execution_timezone.setter
    def execution_timezone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "execution_timezone", value)

    @_builtins.property
    @pulumi.getter(name="targetAccounts")
    def target_accounts(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        """
        return pulumi.get(self, "target_accounts")

    @target_accounts.setter
    def target_accounts(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "target_accounts", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description for rule enforcement.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isDryRun")
    def is_dry_run(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the rule enforcement is a dry run. This by default is set to false.
        """
        return pulumi.get(self, "is_dry_run")

    @is_dry_run.setter
    def is_dry_run(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_dry_run", value)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the rule enforcement is enabled. This by default is set to true.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule enforcement.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ruleIds")
    def rule_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        """
        return pulumi.get(self, "rule_ids")

    @rule_ids.setter
    def rule_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rule_ids", value)

    @_builtins.property
    @pulumi.getter(name="ruleSetIds")
    def rule_set_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        """
        return pulumi.get(self, "rule_set_ids")

    @rule_set_ids.setter
    def rule_set_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rule_set_ids", value)

    @_builtins.property
    @pulumi.getter(name="targetRegions")
    def target_regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        return pulumi.get(self, "target_regions")

    @target_regions.setter
    def target_regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_regions", value)


@pulumi.input_type
class _RuleEnforcementState:
    def __init__(__self__, *,
                 cloud_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enforcement_id: Optional[pulumi.Input[_builtins.str]] = None,
                 execution_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 execution_timezone: Optional[pulumi.Input[_builtins.str]] = None,
                 is_dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rule_set_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_regions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering RuleEnforcement resources.
        :param pulumi.Input[_builtins.str] cloud_provider: The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        :param pulumi.Input[_builtins.str] description: Description for rule enforcement.
        :param pulumi.Input[_builtins.str] enforcement_id: Id of the rule enforcement.
        :param pulumi.Input[_builtins.str] execution_schedule: Execution schedule in cron format.
        :param pulumi.Input[_builtins.str] execution_timezone: Timezone for the execution schedule.
        :param pulumi.Input[_builtins.bool] is_dry_run: Indicates if the rule enforcement is a dry run. This by default is set to false.
        :param pulumi.Input[_builtins.bool] is_enabled: Indicates if the rule enforcement is enabled. This by default is set to true.
        :param pulumi.Input[_builtins.str] name: Name of the rule enforcement.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_ids: List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_set_ids: List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_accounts: List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_regions: List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        if cloud_provider is not None:
            pulumi.set(__self__, "cloud_provider", cloud_provider)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enforcement_id is not None:
            pulumi.set(__self__, "enforcement_id", enforcement_id)
        if execution_schedule is not None:
            pulumi.set(__self__, "execution_schedule", execution_schedule)
        if execution_timezone is not None:
            pulumi.set(__self__, "execution_timezone", execution_timezone)
        if is_dry_run is not None:
            pulumi.set(__self__, "is_dry_run", is_dry_run)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rule_ids is not None:
            pulumi.set(__self__, "rule_ids", rule_ids)
        if rule_set_ids is not None:
            pulumi.set(__self__, "rule_set_ids", rule_set_ids)
        if target_accounts is not None:
            pulumi.set(__self__, "target_accounts", target_accounts)
        if target_regions is not None:
            pulumi.set(__self__, "target_regions", target_regions)

    @_builtins.property
    @pulumi.getter(name="cloudProvider")
    def cloud_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        """
        return pulumi.get(self, "cloud_provider")

    @cloud_provider.setter
    def cloud_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_provider", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description for rule enforcement.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="enforcementId")
    def enforcement_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Id of the rule enforcement.
        """
        return pulumi.get(self, "enforcement_id")

    @enforcement_id.setter
    def enforcement_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enforcement_id", value)

    @_builtins.property
    @pulumi.getter(name="executionSchedule")
    def execution_schedule(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Execution schedule in cron format.
        """
        return pulumi.get(self, "execution_schedule")

    @execution_schedule.setter
    def execution_schedule(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "execution_schedule", value)

    @_builtins.property
    @pulumi.getter(name="executionTimezone")
    def execution_timezone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timezone for the execution schedule.
        """
        return pulumi.get(self, "execution_timezone")

    @execution_timezone.setter
    def execution_timezone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "execution_timezone", value)

    @_builtins.property
    @pulumi.getter(name="isDryRun")
    def is_dry_run(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the rule enforcement is a dry run. This by default is set to false.
        """
        return pulumi.get(self, "is_dry_run")

    @is_dry_run.setter
    def is_dry_run(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_dry_run", value)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the rule enforcement is enabled. This by default is set to true.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule enforcement.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ruleIds")
    def rule_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        """
        return pulumi.get(self, "rule_ids")

    @rule_ids.setter
    def rule_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rule_ids", value)

    @_builtins.property
    @pulumi.getter(name="ruleSetIds")
    def rule_set_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        """
        return pulumi.get(self, "rule_set_ids")

    @rule_set_ids.setter
    def rule_set_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rule_set_ids", value)

    @_builtins.property
    @pulumi.getter(name="targetAccounts")
    def target_accounts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        """
        return pulumi.get(self, "target_accounts")

    @target_accounts.setter
    def target_accounts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_accounts", value)

    @_builtins.property
    @pulumi.getter(name="targetRegions")
    def target_regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        return pulumi.get(self, "target_regions")

    @target_regions.setter
    def target_regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_regions", value)


@pulumi.type_token("harness:governance/ruleEnforcement:RuleEnforcement")
class RuleEnforcement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 execution_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 execution_timezone: Optional[pulumi.Input[_builtins.str]] = None,
                 is_dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rule_set_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_regions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating, updating, and managing rule enforcement.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.governance.RuleEnforcement("example",
            identifier="identifier",
            name="name",
            cloud_provider="AWS/AZURE/GCP",
            rule_ids=["rule_id1"],
            rule_set_ids=["rule_set_id1"],
            execution_schedule="0 0 * * * *",
            execution_timezone="UTC",
            is_enabled=True,
            target_accounts=["awsAccountId/azureSubscriptionId/gcpProjectId"],
            target_regions=["us-east-1/eastus"],
            is_dry_run=False,
            description="description")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import governance enforcement

        ```sh
        $ pulumi import harness:governance/ruleEnforcement:RuleEnforcement example <enforcement_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud_provider: The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        :param pulumi.Input[_builtins.str] description: Description for rule enforcement.
        :param pulumi.Input[_builtins.str] execution_schedule: Execution schedule in cron format.
        :param pulumi.Input[_builtins.str] execution_timezone: Timezone for the execution schedule.
        :param pulumi.Input[_builtins.bool] is_dry_run: Indicates if the rule enforcement is a dry run. This by default is set to false.
        :param pulumi.Input[_builtins.bool] is_enabled: Indicates if the rule enforcement is enabled. This by default is set to true.
        :param pulumi.Input[_builtins.str] name: Name of the rule enforcement.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_ids: List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_set_ids: List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_accounts: List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_regions: List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleEnforcementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating, updating, and managing rule enforcement.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.governance.RuleEnforcement("example",
            identifier="identifier",
            name="name",
            cloud_provider="AWS/AZURE/GCP",
            rule_ids=["rule_id1"],
            rule_set_ids=["rule_set_id1"],
            execution_schedule="0 0 * * * *",
            execution_timezone="UTC",
            is_enabled=True,
            target_accounts=["awsAccountId/azureSubscriptionId/gcpProjectId"],
            target_regions=["us-east-1/eastus"],
            is_dry_run=False,
            description="description")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import governance enforcement

        ```sh
        $ pulumi import harness:governance/ruleEnforcement:RuleEnforcement example <enforcement_id>
        ```

        :param str resource_name: The name of the resource.
        :param RuleEnforcementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleEnforcementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 execution_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 execution_timezone: Optional[pulumi.Input[_builtins.str]] = None,
                 is_dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rule_set_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_regions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleEnforcementArgs.__new__(RuleEnforcementArgs)

            if cloud_provider is None and not opts.urn:
                raise TypeError("Missing required property 'cloud_provider'")
            __props__.__dict__["cloud_provider"] = cloud_provider
            __props__.__dict__["description"] = description
            if execution_schedule is None and not opts.urn:
                raise TypeError("Missing required property 'execution_schedule'")
            __props__.__dict__["execution_schedule"] = execution_schedule
            if execution_timezone is None and not opts.urn:
                raise TypeError("Missing required property 'execution_timezone'")
            __props__.__dict__["execution_timezone"] = execution_timezone
            __props__.__dict__["is_dry_run"] = is_dry_run
            __props__.__dict__["is_enabled"] = is_enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["rule_ids"] = rule_ids
            __props__.__dict__["rule_set_ids"] = rule_set_ids
            if target_accounts is None and not opts.urn:
                raise TypeError("Missing required property 'target_accounts'")
            __props__.__dict__["target_accounts"] = target_accounts
            __props__.__dict__["target_regions"] = target_regions
            __props__.__dict__["enforcement_id"] = None
        super(RuleEnforcement, __self__).__init__(
            'harness:governance/ruleEnforcement:RuleEnforcement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_provider: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enforcement_id: Optional[pulumi.Input[_builtins.str]] = None,
            execution_schedule: Optional[pulumi.Input[_builtins.str]] = None,
            execution_timezone: Optional[pulumi.Input[_builtins.str]] = None,
            is_dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
            is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            rule_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            rule_set_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            target_accounts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            target_regions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'RuleEnforcement':
        """
        Get an existing RuleEnforcement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud_provider: The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        :param pulumi.Input[_builtins.str] description: Description for rule enforcement.
        :param pulumi.Input[_builtins.str] enforcement_id: Id of the rule enforcement.
        :param pulumi.Input[_builtins.str] execution_schedule: Execution schedule in cron format.
        :param pulumi.Input[_builtins.str] execution_timezone: Timezone for the execution schedule.
        :param pulumi.Input[_builtins.bool] is_dry_run: Indicates if the rule enforcement is a dry run. This by default is set to false.
        :param pulumi.Input[_builtins.bool] is_enabled: Indicates if the rule enforcement is enabled. This by default is set to true.
        :param pulumi.Input[_builtins.str] name: Name of the rule enforcement.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_ids: List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rule_set_ids: List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_accounts: List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_regions: List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleEnforcementState.__new__(_RuleEnforcementState)

        __props__.__dict__["cloud_provider"] = cloud_provider
        __props__.__dict__["description"] = description
        __props__.__dict__["enforcement_id"] = enforcement_id
        __props__.__dict__["execution_schedule"] = execution_schedule
        __props__.__dict__["execution_timezone"] = execution_timezone
        __props__.__dict__["is_dry_run"] = is_dry_run
        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["rule_ids"] = rule_ids
        __props__.__dict__["rule_set_ids"] = rule_set_ids
        __props__.__dict__["target_accounts"] = target_accounts
        __props__.__dict__["target_regions"] = target_regions
        return RuleEnforcement(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="cloudProvider")
    def cloud_provider(self) -> pulumi.Output[_builtins.str]:
        """
        The cloud provider for the rule enforcement. It should be either AWS, AZURE or GCP.
        """
        return pulumi.get(self, "cloud_provider")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description for rule enforcement.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="enforcementId")
    def enforcement_id(self) -> pulumi.Output[_builtins.str]:
        """
        Id of the rule enforcement.
        """
        return pulumi.get(self, "enforcement_id")

    @_builtins.property
    @pulumi.getter(name="executionSchedule")
    def execution_schedule(self) -> pulumi.Output[_builtins.str]:
        """
        Execution schedule in cron format.
        """
        return pulumi.get(self, "execution_schedule")

    @_builtins.property
    @pulumi.getter(name="executionTimezone")
    def execution_timezone(self) -> pulumi.Output[_builtins.str]:
        """
        Timezone for the execution schedule.
        """
        return pulumi.get(self, "execution_timezone")

    @_builtins.property
    @pulumi.getter(name="isDryRun")
    def is_dry_run(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the rule enforcement is a dry run. This by default is set to false.
        """
        return pulumi.get(self, "is_dry_run")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the rule enforcement is enabled. This by default is set to true.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the rule enforcement.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ruleIds")
    def rule_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of rule IDs. Either rule*ids or rule*set_ids should be provided.
        """
        return pulumi.get(self, "rule_ids")

    @_builtins.property
    @pulumi.getter(name="ruleSetIds")
    def rule_set_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of rule set IDs. Either rule*ids or rule*set_ids should be provided.
        """
        return pulumi.get(self, "rule_set_ids")

    @_builtins.property
    @pulumi.getter(name="targetAccounts")
    def target_accounts(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of target account which can be either AWS Account Ids or Azure Subscription Ids or Gcp Project Ids.
        """
        return pulumi.get(self, "target_accounts")

    @_builtins.property
    @pulumi.getter(name="targetRegions")
    def target_regions(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of target regions. For GCP it should be left empty but is required in case of AWS or Azure.
        """
        return pulumi.get(self, "target_regions")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAwsAlbResult',
    'AwaitableGetAwsAlbResult',
    'get_aws_alb',
    'get_aws_alb_output',
]

@pulumi.output_type
class GetAwsAlbResult:
    """
    A collection of values returned by getAwsAlb.
    """
    def __init__(__self__, alb_arn=None, certificate_id=None, cloud_connector_id=None, delete_cloud_resources_on_destroy=None, host_name=None, id=None, identifier=None, name=None, region=None, route53_hosted_zone_id=None, security_groups=None, vpc=None):
        if alb_arn and not isinstance(alb_arn, str):
            raise TypeError("Expected argument 'alb_arn' to be a str")
        pulumi.set(__self__, "alb_arn", alb_arn)
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if cloud_connector_id and not isinstance(cloud_connector_id, str):
            raise TypeError("Expected argument 'cloud_connector_id' to be a str")
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if delete_cloud_resources_on_destroy and not isinstance(delete_cloud_resources_on_destroy, bool):
            raise TypeError("Expected argument 'delete_cloud_resources_on_destroy' to be a bool")
        pulumi.set(__self__, "delete_cloud_resources_on_destroy", delete_cloud_resources_on_destroy)
        if host_name and not isinstance(host_name, str):
            raise TypeError("Expected argument 'host_name' to be a str")
        pulumi.set(__self__, "host_name", host_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if route53_hosted_zone_id and not isinstance(route53_hosted_zone_id, str):
            raise TypeError("Expected argument 'route53_hosted_zone_id' to be a str")
        pulumi.set(__self__, "route53_hosted_zone_id", route53_hosted_zone_id)
        if security_groups and not isinstance(security_groups, list):
            raise TypeError("Expected argument 'security_groups' to be a list")
        pulumi.set(__self__, "security_groups", security_groups)
        if vpc and not isinstance(vpc, str):
            raise TypeError("Expected argument 'vpc' to be a str")
        pulumi.set(__self__, "vpc", vpc)

    @_builtins.property
    @pulumi.getter(name="albArn")
    def alb_arn(self) -> Optional[_builtins.str]:
        """
        Arn of AWS ALB to be imported. Required only for importing existing ALB
        """
        return pulumi.get(self, "alb_arn")

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "certificate_id")

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> _builtins.str:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter(name="deleteCloudResourcesOnDestroy")
    def delete_cloud_resources_on_destroy(self) -> _builtins.bool:
        return pulumi.get(self, "delete_cloud_resources_on_destroy")

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> _builtins.str:
        """
        Hostname for the proxy
        """
        return pulumi.get(self, "host_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the proxy
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Region in which cloud resources are hosted
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="route53HostedZoneId")
    def route53_hosted_zone_id(self) -> Optional[_builtins.str]:
        """
        Route 53 hosted zone id
        """
        return pulumi.get(self, "route53_hosted_zone_id")

    @_builtins.property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> Optional[Sequence[_builtins.str]]:
        """
        Security Group to define the security rules that determine the inbound and outbound traffic
        """
        return pulumi.get(self, "security_groups")

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> _builtins.str:
        """
        VPC in which cloud resources are hosted
        """
        return pulumi.get(self, "vpc")


class AwaitableGetAwsAlbResult(GetAwsAlbResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsAlbResult(
            alb_arn=self.alb_arn,
            certificate_id=self.certificate_id,
            cloud_connector_id=self.cloud_connector_id,
            delete_cloud_resources_on_destroy=self.delete_cloud_resources_on_destroy,
            host_name=self.host_name,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            region=self.region,
            route53_hosted_zone_id=self.route53_hosted_zone_id,
            security_groups=self.security_groups,
            vpc=self.vpc)


def get_aws_alb(alb_arn: Optional[_builtins.str] = None,
                certificate_id: Optional[_builtins.str] = None,
                cloud_connector_id: Optional[_builtins.str] = None,
                delete_cloud_resources_on_destroy: Optional[_builtins.bool] = None,
                host_name: Optional[_builtins.str] = None,
                name: Optional[_builtins.str] = None,
                region: Optional[_builtins.str] = None,
                route53_hosted_zone_id: Optional[_builtins.str] = None,
                security_groups: Optional[Sequence[_builtins.str]] = None,
                vpc: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsAlbResult:
    """
    Data source for AWS Autostopping proxy

    ## Example Usage


    :param _builtins.str alb_arn: Arn of AWS ALB to be imported. Required only for importing existing ALB
    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param _builtins.str host_name: Hostname for the proxy
    :param _builtins.str name: Name of the proxy
    :param _builtins.str region: Region in which cloud resources are hosted
    :param _builtins.str route53_hosted_zone_id: Route 53 hosted zone id
    :param Sequence[_builtins.str] security_groups: Security Group to define the security rules that determine the inbound and outbound traffic
    :param _builtins.str vpc: VPC in which cloud resources are hosted
    """
    __args__ = dict()
    __args__['albArn'] = alb_arn
    __args__['certificateId'] = certificate_id
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['deleteCloudResourcesOnDestroy'] = delete_cloud_resources_on_destroy
    __args__['hostName'] = host_name
    __args__['name'] = name
    __args__['region'] = region
    __args__['route53HostedZoneId'] = route53_hosted_zone_id
    __args__['securityGroups'] = security_groups
    __args__['vpc'] = vpc
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:autostopping/getAwsAlb:getAwsAlb', __args__, opts=opts, typ=GetAwsAlbResult).value

    return AwaitableGetAwsAlbResult(
        alb_arn=pulumi.get(__ret__, 'alb_arn'),
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        cloud_connector_id=pulumi.get(__ret__, 'cloud_connector_id'),
        delete_cloud_resources_on_destroy=pulumi.get(__ret__, 'delete_cloud_resources_on_destroy'),
        host_name=pulumi.get(__ret__, 'host_name'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        route53_hosted_zone_id=pulumi.get(__ret__, 'route53_hosted_zone_id'),
        security_groups=pulumi.get(__ret__, 'security_groups'),
        vpc=pulumi.get(__ret__, 'vpc'))
def get_aws_alb_output(alb_arn: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       certificate_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                       delete_cloud_resources_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                       host_name: Optional[pulumi.Input[_builtins.str]] = None,
                       name: Optional[pulumi.Input[_builtins.str]] = None,
                       region: Optional[pulumi.Input[_builtins.str]] = None,
                       route53_hosted_zone_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       security_groups: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                       vpc: Optional[pulumi.Input[_builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAwsAlbResult]:
    """
    Data source for AWS Autostopping proxy

    ## Example Usage


    :param _builtins.str alb_arn: Arn of AWS ALB to be imported. Required only for importing existing ALB
    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param _builtins.str host_name: Hostname for the proxy
    :param _builtins.str name: Name of the proxy
    :param _builtins.str region: Region in which cloud resources are hosted
    :param _builtins.str route53_hosted_zone_id: Route 53 hosted zone id
    :param Sequence[_builtins.str] security_groups: Security Group to define the security rules that determine the inbound and outbound traffic
    :param _builtins.str vpc: VPC in which cloud resources are hosted
    """
    __args__ = dict()
    __args__['albArn'] = alb_arn
    __args__['certificateId'] = certificate_id
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['deleteCloudResourcesOnDestroy'] = delete_cloud_resources_on_destroy
    __args__['hostName'] = host_name
    __args__['name'] = name
    __args__['region'] = region
    __args__['route53HostedZoneId'] = route53_hosted_zone_id
    __args__['securityGroups'] = security_groups
    __args__['vpc'] = vpc
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:autostopping/getAwsAlb:getAwsAlb', __args__, opts=opts, typ=GetAwsAlbResult)
    return __ret__.apply(lambda __response__: GetAwsAlbResult(
        alb_arn=pulumi.get(__response__, 'alb_arn'),
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        cloud_connector_id=pulumi.get(__response__, 'cloud_connector_id'),
        delete_cloud_resources_on_destroy=pulumi.get(__response__, 'delete_cloud_resources_on_destroy'),
        host_name=pulumi.get(__response__, 'host_name'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        route53_hosted_zone_id=pulumi.get(__response__, 'route53_hosted_zone_id'),
        security_groups=pulumi.get(__response__, 'security_groups'),
        vpc=pulumi.get(__response__, 'vpc')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecretWinrmArgs', 'SecretWinrm']

@pulumi.input_type
class SecretWinrmArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 kerberos: Optional[pulumi.Input['SecretWinrmKerberosArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ntlm: Optional[pulumi.Input['SecretWinrmNtlmArgs']] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a SecretWinrm resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['SecretWinrmKerberosArgs'] kerberos: Kerberos authentication scheme
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['SecretWinrmNtlmArgs'] ntlm: NTLM authentication scheme
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.int] port: WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "identifier", identifier)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kerberos is not None:
            pulumi.set(__self__, "kerberos", kerberos)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ntlm is not None:
            pulumi.set(__self__, "ntlm", ntlm)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def kerberos(self) -> Optional[pulumi.Input['SecretWinrmKerberosArgs']]:
        """
        Kerberos authentication scheme
        """
        return pulumi.get(self, "kerberos")

    @kerberos.setter
    def kerberos(self, value: Optional[pulumi.Input['SecretWinrmKerberosArgs']]):
        pulumi.set(self, "kerberos", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def ntlm(self) -> Optional[pulumi.Input['SecretWinrmNtlmArgs']]:
        """
        NTLM authentication scheme
        """
        return pulumi.get(self, "ntlm")

    @ntlm.setter
    def ntlm(self, value: Optional[pulumi.Input['SecretWinrmNtlmArgs']]):
        pulumi.set(self, "ntlm", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SecretWinrmState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kerberos: Optional[pulumi.Input['SecretWinrmKerberosArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ntlm: Optional[pulumi.Input['SecretWinrmNtlmArgs']] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SecretWinrm resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input['SecretWinrmKerberosArgs'] kerberos: Kerberos authentication scheme
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['SecretWinrmNtlmArgs'] ntlm: NTLM authentication scheme
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.int] port: WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if kerberos is not None:
            pulumi.set(__self__, "kerberos", kerberos)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ntlm is not None:
            pulumi.set(__self__, "ntlm", ntlm)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def kerberos(self) -> Optional[pulumi.Input['SecretWinrmKerberosArgs']]:
        """
        Kerberos authentication scheme
        """
        return pulumi.get(self, "kerberos")

    @kerberos.setter
    def kerberos(self, value: Optional[pulumi.Input['SecretWinrmKerberosArgs']]):
        pulumi.set(self, "kerberos", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def ntlm(self) -> Optional[pulumi.Input['SecretWinrmNtlmArgs']]:
        """
        NTLM authentication scheme
        """
        return pulumi.get(self, "ntlm")

    @ntlm.setter
    def ntlm(self, value: Optional[pulumi.Input['SecretWinrmNtlmArgs']]):
        pulumi.set(self, "ntlm", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/secretWinrm:SecretWinrm")
class SecretWinrm(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kerberos: Optional[pulumi.Input[Union['SecretWinrmKerberosArgs', 'SecretWinrmKerberosArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ntlm: Optional[pulumi.Input[Union['SecretWinrmNtlmArgs', 'SecretWinrmNtlmArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a WinRM credential secret.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # ============================================================================
        # ACCOUNT LEVEL TESTS (3 scenarios)
        # ============================================================================
        # 1. Account-level NTLM
        account_ntlm_password = harness.platform.SecretText("account_ntlm_password",
            identifier="account_ntlm_password_v3",
            name="account_ntlm_password_v3",
            description="Password for account-level NTLM",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="account_ntlm_pass")
        account_ntlm = harness.platform.SecretWinrm("account_ntlm",
            identifier="account_ntlm_v3",
            name="Account NTLM v3",
            description="Account-level WinRM with NTLM",
            tags=[
                "scope:account",
                "auth:ntlm",
            ],
            port=5986,
            ntlm={
                "domain": "example.com",
                "username": "admin",
                "password_ref": account_ntlm_password.id.apply(lambda id: f"account.{id}"),
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": True,
            })
        # 2. Account-level Kerberos with KeyTab
        account_kerberos_keytab = harness.platform.SecretWinrm("account_kerberos_keytab",
            identifier="account_kerberos_keytab_v3",
            name="Account Kerberos KeyTab v3",
            description="Account-level WinRM with Kerberos KeyTab",
            tags=[
                "scope:account",
                "auth:kerberos-keytab",
            ],
            port=5986,
            kerberos={
                "principal": "service@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "KeyTabFilePath",
                "use_ssl": True,
                "skip_cert_check": True,
                "use_no_profile": True,
                "tgt_key_tab_file_path_spec": {
                    "key_path": "/etc/krb5.keytab",
                },
            })
        # 3. Account-level Kerberos with Password
        account_kerberos_password1 = harness.platform.SecretText("account_kerberos_password_1",
            identifier="account_kerb_pass_20251111",
            name="account_kerb_pass_20251111",
            description="Password for account-level Kerberos",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="account_kerberos_pass")
        account_kerberos_password1_secret_winrm = harness.platform.SecretWinrm("account_kerberos_password_1",
            identifier="account_kerb_winrm_20251111",
            name="Account Kerberos WinRM 20251111",
            description="Account-level WinRM with Kerberos Password",
            tags=[
                "scope:account",
                "auth:kerberos-password",
            ],
            port=5986,
            kerberos={
                "principal": "user@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "Password",
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": True,
                "tgt_password_spec": {
                    "password_ref": account_kerberos_password1.id.apply(lambda id: f"account.{id}"),
                },
            })
        # ============================================================================
        # ORGANIZATION LEVEL TESTS (3 scenarios)
        # ============================================================================
        # 4. Org-level NTLM
        org_ntlm_password = harness.platform.SecretText("org_ntlm_password",
            identifier="org_ntlm_password_v3",
            name="org_ntlm_password_v3",
            description="Password for org-level NTLM",
            org_id="default",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="org_ntlm_pass")
        org_ntlm = harness.platform.SecretWinrm("org_ntlm",
            identifier="org_ntlm_v3",
            name="Org NTLM v3",
            description="Org-level WinRM with NTLM",
            org_id="default",
            tags=[
                "scope:org",
                "auth:ntlm",
            ],
            port=5985,
            ntlm={
                "domain": "org.example.com",
                "username": "orgadmin",
                "password_ref": org_ntlm_password.id.apply(lambda id: f"org.{id}"),
                "use_ssl": False,
                "skip_cert_check": False,
                "use_no_profile": True,
            })
        # 5. Org-level Kerberos with KeyTab
        org_kerberos_keytab = harness.platform.SecretWinrm("org_kerberos_keytab",
            identifier="org_kerberos_keytab_v3",
            name="Org Kerberos KeyTab v3",
            description="Org-level WinRM with Kerberos KeyTab",
            org_id="default",
            tags=[
                "scope:org",
                "auth:kerberos-keytab",
            ],
            port=5986,
            kerberos={
                "principal": "orgservice@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "KeyTabFilePath",
                "use_ssl": True,
                "skip_cert_check": True,
                "use_no_profile": True,
                "tgt_key_tab_file_path_spec": {
                    "key_path": "/etc/org.keytab",
                },
            })
        # 6. Org-level Kerberos with Password
        org_kerberos_password = harness.platform.SecretText("org_kerberos_password",
            identifier="org_kerb_pass_v3",
            name="org_kerb_pass_v3",
            description="Password for org-level Kerberos",
            org_id="default",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="org_kerberos_pass")
        org_kerberos_password_secret_winrm = harness.platform.SecretWinrm("org_kerberos_password",
            identifier="org_kerb_winrm_v3",
            name="Org Kerberos WinRM v3",
            description="Org-level WinRM with Kerberos Password",
            org_id="default",
            tags=[
                "scope:org",
                "auth:kerberos-password",
            ],
            port=5986,
            kerberos={
                "principal": "orguser@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "Password",
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": True,
                "tgt_password_spec": {
                    "password_ref": org_kerberos_password.id.apply(lambda id: f"org.{id}"),
                },
            })
        # ============================================================================
        # PROJECT LEVEL TESTS (3 scenarios)
        # ============================================================================
        # 7. Project-level NTLM
        project_ntlm_password = harness.platform.SecretText("project_ntlm_password",
            identifier="proj_ntlm_pass_v3",
            name="proj_ntlm_pass_v3",
            description="Password for project-level NTLM",
            org_id="default",
            project_id="winrm_support_terraform",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="project_ntlm_pass")
        project_ntlm = harness.platform.SecretWinrm("project_ntlm",
            identifier="proj_ntlm_winrm_v3",
            name="Project NTLM WinRM v3",
            description="Project-level WinRM with NTLM",
            org_id="default",
            project_id="winrm_support_terraform",
            tags=[
                "scope:project",
                "auth:ntlm",
            ],
            port=5986,
            ntlm={
                "domain": "project.example.com",
                "username": "projectadmin",
                "password_ref": project_ntlm_password.id,
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": False,
            })
        # 8. Project-level Kerberos with KeyTab
        project_kerberos_keytab = harness.platform.SecretWinrm("project_kerberos_keytab",
            identifier="proj_kerb_keytab_v3",
            name="Project Kerberos KeyTab v3",
            description="Project-level WinRM with Kerberos KeyTab",
            org_id="default",
            project_id="winrm_support_terraform",
            tags=[
                "scope:project",
                "auth:kerberos-keytab",
            ],
            port=5986,
            kerberos={
                "principal": "projectservice@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "KeyTabFilePath",
                "use_ssl": False,
                "skip_cert_check": False,
                "use_no_profile": False,
                "tgt_key_tab_file_path_spec": {
                    "key_path": "/etc/project.keytab",
                },
            })
        # 9. Project-level Kerberos with Password
        project_kerberos_password = harness.platform.SecretText("project_kerberos_password",
            identifier="proj_kerb_pass_v3",
            name="proj_kerb_pass_v3",
            description="Password for project-level Kerberos",
            org_id="default",
            project_id="winrm_support_terraform",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="project_kerberos_pass")
        project_kerberos_password_secret_winrm = harness.platform.SecretWinrm("project_kerberos_password",
            identifier="proj_kerb_winrm_v3",
            name="Project Kerberos WinRM v3",
            description="Project-level WinRM with Kerberos Password",
            org_id="default",
            project_id="winrm_support_terraform",
            tags=[
                "scope:project",
                "auth:kerberos-password",
            ],
            port=5986,
            kerberos={
                "principal": "projectuser@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "Password",
                "use_ssl": False,
                "skip_cert_check": True,
                "use_no_profile": True,
                "tgt_password_spec": {
                    "password_ref": project_kerberos_password.id,
                },
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level WinRM credential

        ```sh
        $ pulumi import harness:platform/secretWinrm:SecretWinrm example <winrm_credential_id>
        ```

        Import organization level WinRM credential

        ```sh
        $ pulumi import harness:platform/secretWinrm:SecretWinrm example <org_id>/<winrm_credential_id>
        ```

        Import project level WinRM credential

        ```sh
        $ pulumi import harness:platform/secretWinrm:SecretWinrm example <org_id>/<project_id>/<winrm_credential_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Union['SecretWinrmKerberosArgs', 'SecretWinrmKerberosArgsDict']] kerberos: Kerberos authentication scheme
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Union['SecretWinrmNtlmArgs', 'SecretWinrmNtlmArgsDict']] ntlm: NTLM authentication scheme
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.int] port: WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretWinrmArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a WinRM credential secret.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # ============================================================================
        # ACCOUNT LEVEL TESTS (3 scenarios)
        # ============================================================================
        # 1. Account-level NTLM
        account_ntlm_password = harness.platform.SecretText("account_ntlm_password",
            identifier="account_ntlm_password_v3",
            name="account_ntlm_password_v3",
            description="Password for account-level NTLM",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="account_ntlm_pass")
        account_ntlm = harness.platform.SecretWinrm("account_ntlm",
            identifier="account_ntlm_v3",
            name="Account NTLM v3",
            description="Account-level WinRM with NTLM",
            tags=[
                "scope:account",
                "auth:ntlm",
            ],
            port=5986,
            ntlm={
                "domain": "example.com",
                "username": "admin",
                "password_ref": account_ntlm_password.id.apply(lambda id: f"account.{id}"),
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": True,
            })
        # 2. Account-level Kerberos with KeyTab
        account_kerberos_keytab = harness.platform.SecretWinrm("account_kerberos_keytab",
            identifier="account_kerberos_keytab_v3",
            name="Account Kerberos KeyTab v3",
            description="Account-level WinRM with Kerberos KeyTab",
            tags=[
                "scope:account",
                "auth:kerberos-keytab",
            ],
            port=5986,
            kerberos={
                "principal": "service@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "KeyTabFilePath",
                "use_ssl": True,
                "skip_cert_check": True,
                "use_no_profile": True,
                "tgt_key_tab_file_path_spec": {
                    "key_path": "/etc/krb5.keytab",
                },
            })
        # 3. Account-level Kerberos with Password
        account_kerberos_password1 = harness.platform.SecretText("account_kerberos_password_1",
            identifier="account_kerb_pass_20251111",
            name="account_kerb_pass_20251111",
            description="Password for account-level Kerberos",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="account_kerberos_pass")
        account_kerberos_password1_secret_winrm = harness.platform.SecretWinrm("account_kerberos_password_1",
            identifier="account_kerb_winrm_20251111",
            name="Account Kerberos WinRM 20251111",
            description="Account-level WinRM with Kerberos Password",
            tags=[
                "scope:account",
                "auth:kerberos-password",
            ],
            port=5986,
            kerberos={
                "principal": "user@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "Password",
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": True,
                "tgt_password_spec": {
                    "password_ref": account_kerberos_password1.id.apply(lambda id: f"account.{id}"),
                },
            })
        # ============================================================================
        # ORGANIZATION LEVEL TESTS (3 scenarios)
        # ============================================================================
        # 4. Org-level NTLM
        org_ntlm_password = harness.platform.SecretText("org_ntlm_password",
            identifier="org_ntlm_password_v3",
            name="org_ntlm_password_v3",
            description="Password for org-level NTLM",
            org_id="default",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="org_ntlm_pass")
        org_ntlm = harness.platform.SecretWinrm("org_ntlm",
            identifier="org_ntlm_v3",
            name="Org NTLM v3",
            description="Org-level WinRM with NTLM",
            org_id="default",
            tags=[
                "scope:org",
                "auth:ntlm",
            ],
            port=5985,
            ntlm={
                "domain": "org.example.com",
                "username": "orgadmin",
                "password_ref": org_ntlm_password.id.apply(lambda id: f"org.{id}"),
                "use_ssl": False,
                "skip_cert_check": False,
                "use_no_profile": True,
            })
        # 5. Org-level Kerberos with KeyTab
        org_kerberos_keytab = harness.platform.SecretWinrm("org_kerberos_keytab",
            identifier="org_kerberos_keytab_v3",
            name="Org Kerberos KeyTab v3",
            description="Org-level WinRM with Kerberos KeyTab",
            org_id="default",
            tags=[
                "scope:org",
                "auth:kerberos-keytab",
            ],
            port=5986,
            kerberos={
                "principal": "orgservice@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "KeyTabFilePath",
                "use_ssl": True,
                "skip_cert_check": True,
                "use_no_profile": True,
                "tgt_key_tab_file_path_spec": {
                    "key_path": "/etc/org.keytab",
                },
            })
        # 6. Org-level Kerberos with Password
        org_kerberos_password = harness.platform.SecretText("org_kerberos_password",
            identifier="org_kerb_pass_v3",
            name="org_kerb_pass_v3",
            description="Password for org-level Kerberos",
            org_id="default",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="org_kerberos_pass")
        org_kerberos_password_secret_winrm = harness.platform.SecretWinrm("org_kerberos_password",
            identifier="org_kerb_winrm_v3",
            name="Org Kerberos WinRM v3",
            description="Org-level WinRM with Kerberos Password",
            org_id="default",
            tags=[
                "scope:org",
                "auth:kerberos-password",
            ],
            port=5986,
            kerberos={
                "principal": "orguser@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "Password",
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": True,
                "tgt_password_spec": {
                    "password_ref": org_kerberos_password.id.apply(lambda id: f"org.{id}"),
                },
            })
        # ============================================================================
        # PROJECT LEVEL TESTS (3 scenarios)
        # ============================================================================
        # 7. Project-level NTLM
        project_ntlm_password = harness.platform.SecretText("project_ntlm_password",
            identifier="proj_ntlm_pass_v3",
            name="proj_ntlm_pass_v3",
            description="Password for project-level NTLM",
            org_id="default",
            project_id="winrm_support_terraform",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="project_ntlm_pass")
        project_ntlm = harness.platform.SecretWinrm("project_ntlm",
            identifier="proj_ntlm_winrm_v3",
            name="Project NTLM WinRM v3",
            description="Project-level WinRM with NTLM",
            org_id="default",
            project_id="winrm_support_terraform",
            tags=[
                "scope:project",
                "auth:ntlm",
            ],
            port=5986,
            ntlm={
                "domain": "project.example.com",
                "username": "projectadmin",
                "password_ref": project_ntlm_password.id,
                "use_ssl": True,
                "skip_cert_check": False,
                "use_no_profile": False,
            })
        # 8. Project-level Kerberos with KeyTab
        project_kerberos_keytab = harness.platform.SecretWinrm("project_kerberos_keytab",
            identifier="proj_kerb_keytab_v3",
            name="Project Kerberos KeyTab v3",
            description="Project-level WinRM with Kerberos KeyTab",
            org_id="default",
            project_id="winrm_support_terraform",
            tags=[
                "scope:project",
                "auth:kerberos-keytab",
            ],
            port=5986,
            kerberos={
                "principal": "projectservice@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "KeyTabFilePath",
                "use_ssl": False,
                "skip_cert_check": False,
                "use_no_profile": False,
                "tgt_key_tab_file_path_spec": {
                    "key_path": "/etc/project.keytab",
                },
            })
        # 9. Project-level Kerberos with Password
        project_kerberos_password = harness.platform.SecretText("project_kerberos_password",
            identifier="proj_kerb_pass_v3",
            name="proj_kerb_pass_v3",
            description="Password for project-level Kerberos",
            org_id="default",
            project_id="winrm_support_terraform",
            secret_manager_identifier="harnessSecretManager",
            value_type="Inline",
            value="project_kerberos_pass")
        project_kerberos_password_secret_winrm = harness.platform.SecretWinrm("project_kerberos_password",
            identifier="proj_kerb_winrm_v3",
            name="Project Kerberos WinRM v3",
            description="Project-level WinRM with Kerberos Password",
            org_id="default",
            project_id="winrm_support_terraform",
            tags=[
                "scope:project",
                "auth:kerberos-password",
            ],
            port=5986,
            kerberos={
                "principal": "projectuser@EXAMPLE.COM",
                "realm": "EXAMPLE.COM",
                "tgt_generation_method": "Password",
                "use_ssl": False,
                "skip_cert_check": True,
                "use_no_profile": True,
                "tgt_password_spec": {
                    "password_ref": project_kerberos_password.id,
                },
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level WinRM credential

        ```sh
        $ pulumi import harness:platform/secretWinrm:SecretWinrm example <winrm_credential_id>
        ```

        Import organization level WinRM credential

        ```sh
        $ pulumi import harness:platform/secretWinrm:SecretWinrm example <org_id>/<winrm_credential_id>
        ```

        Import project level WinRM credential

        ```sh
        $ pulumi import harness:platform/secretWinrm:SecretWinrm example <org_id>/<project_id>/<winrm_credential_id>
        ```

        :param str resource_name: The name of the resource.
        :param SecretWinrmArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretWinrmArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kerberos: Optional[pulumi.Input[Union['SecretWinrmKerberosArgs', 'SecretWinrmKerberosArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ntlm: Optional[pulumi.Input[Union['SecretWinrmNtlmArgs', 'SecretWinrmNtlmArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretWinrmArgs.__new__(SecretWinrmArgs)

            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["kerberos"] = kerberos
            __props__.__dict__["name"] = name
            __props__.__dict__["ntlm"] = ntlm
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["port"] = port
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
        super(SecretWinrm, __self__).__init__(
            'harness:platform/secretWinrm:SecretWinrm',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            kerberos: Optional[pulumi.Input[Union['SecretWinrmKerberosArgs', 'SecretWinrmKerberosArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            ntlm: Optional[pulumi.Input[Union['SecretWinrmNtlmArgs', 'SecretWinrmNtlmArgsDict']]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'SecretWinrm':
        """
        Get an existing SecretWinrm resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Union['SecretWinrmKerberosArgs', 'SecretWinrmKerberosArgsDict']] kerberos: Kerberos authentication scheme
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Union['SecretWinrmNtlmArgs', 'SecretWinrmNtlmArgsDict']] ntlm: NTLM authentication scheme
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.int] port: WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretWinrmState.__new__(_SecretWinrmState)

        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["kerberos"] = kerberos
        __props__.__dict__["name"] = name
        __props__.__dict__["ntlm"] = ntlm
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["port"] = port
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        return SecretWinrm(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def kerberos(self) -> pulumi.Output[Optional['outputs.SecretWinrmKerberos']]:
        """
        Kerberos authentication scheme
        """
        return pulumi.get(self, "kerberos")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def ntlm(self) -> pulumi.Output[Optional['outputs.SecretWinrmNtlm']]:
        """
        NTLM authentication scheme
        """
        return pulumi.get(self, "ntlm")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        WinRM port. Default is 5986 for HTTPS, 5985 for HTTP.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetApiKeyResult',
    'AwaitableGetApiKeyResult',
    'get_api_key',
    'get_api_key_output',
]

@pulumi.output_type
class GetApiKeyResult:
    """
    A collection of values returned by getApiKey.
    """
    def __init__(__self__, account_id=None, apikey_type=None, default_time_to_expire_token=None, description=None, id=None, identifier=None, name=None, org_id=None, parent_id=None, project_id=None, tags=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if apikey_type and not isinstance(apikey_type, str):
            raise TypeError("Expected argument 'apikey_type' to be a str")
        pulumi.set(__self__, "apikey_type", apikey_type)
        if default_time_to_expire_token and not isinstance(default_time_to_expire_token, int):
            raise TypeError("Expected argument 'default_time_to_expire_token' to be a int")
        pulumi.set(__self__, "default_time_to_expire_token", default_time_to_expire_token)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if parent_id and not isinstance(parent_id, str):
            raise TypeError("Expected argument 'parent_id' to be a str")
        pulumi.set(__self__, "parent_id", parent_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> _builtins.str:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @_builtins.property
    @pulumi.getter(name="defaultTimeToExpireToken")
    def default_time_to_expire_token(self) -> Optional[_builtins.int]:
        """
        Expiry time of the apiKey
        """
        return pulumi.get(self, "default_time_to_expire_token")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> _builtins.str:
        """
        Parent Identifier for the Entity
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetApiKeyResult(GetApiKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApiKeyResult(
            account_id=self.account_id,
            apikey_type=self.apikey_type,
            default_time_to_expire_token=self.default_time_to_expire_token,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            parent_id=self.parent_id,
            project_id=self.project_id,
            tags=self.tags)


def get_api_key(account_id: Optional[_builtins.str] = None,
                apikey_type: Optional[_builtins.str] = None,
                default_time_to_expire_token: Optional[_builtins.int] = None,
                identifier: Optional[_builtins.str] = None,
                name: Optional[_builtins.str] = None,
                org_id: Optional[_builtins.str] = None,
                parent_id: Optional[_builtins.str] = None,
                project_id: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApiKeyResult:
    """
    Data source for retrieving a Harness ApiKey.


    :param _builtins.str account_id: Account Identifier for the Entity
    :param _builtins.str apikey_type: Type of the API Key
    :param _builtins.int default_time_to_expire_token: Expiry time of the apiKey
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str parent_id: Parent Identifier for the Entity
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['apikeyType'] = apikey_type
    __args__['defaultTimeToExpireToken'] = default_time_to_expire_token
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['parentId'] = parent_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getApiKey:getApiKey', __args__, opts=opts, typ=GetApiKeyResult).value

    return AwaitableGetApiKeyResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        apikey_type=pulumi.get(__ret__, 'apikey_type'),
        default_time_to_expire_token=pulumi.get(__ret__, 'default_time_to_expire_token'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        parent_id=pulumi.get(__ret__, 'parent_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_api_key_output(account_id: Optional[pulumi.Input[_builtins.str]] = None,
                       apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                       default_time_to_expire_token: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                       identifier: Optional[pulumi.Input[_builtins.str]] = None,
                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                       project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApiKeyResult]:
    """
    Data source for retrieving a Harness ApiKey.


    :param _builtins.str account_id: Account Identifier for the Entity
    :param _builtins.str apikey_type: Type of the API Key
    :param _builtins.int default_time_to_expire_token: Expiry time of the apiKey
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str parent_id: Parent Identifier for the Entity
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['apikeyType'] = apikey_type
    __args__['defaultTimeToExpireToken'] = default_time_to_expire_token
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['parentId'] = parent_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getApiKey:getApiKey', __args__, opts=opts, typ=GetApiKeyResult)
    return __ret__.apply(lambda __response__: GetApiKeyResult(
        account_id=pulumi.get(__response__, 'account_id'),
        apikey_type=pulumi.get(__response__, 'apikey_type'),
        default_time_to_expire_token=pulumi.get(__response__, 'default_time_to_expire_token'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        parent_id=pulumi.get(__response__, 'parent_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ImageRegistryArgs', 'ImageRegistry']

@pulumi.input_type
class ImageRegistryArgs:
    def __init__(__self__, *,
                 is_private: pulumi.Input[_builtins.bool],
                 registry_account: pulumi.Input[_builtins.str],
                 registry_server: pulumi.Input[_builtins.str],
                 custom_images: Optional[pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_override_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 use_custom_images: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ImageRegistry resource.
        :param pulumi.Input[_builtins.bool] is_private: Whether the registry is private
        :param pulumi.Input[_builtins.str] registry_account: The registry account name
        :param pulumi.Input[_builtins.str] registry_server: The registry server URL
        :param pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]] custom_images: Custom images configuration
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to set up the image registry
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default registry
        :param pulumi.Input[_builtins.bool] is_override_allowed: Whether override is allowed for this registry
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the image registry
        :param pulumi.Input[_builtins.str] project_id: The project ID of the image registry
        :param pulumi.Input[_builtins.str] secret_name: The name of the secret for authentication
        :param pulumi.Input[_builtins.bool] use_custom_images: Whether to use custom images
        """
        pulumi.set(__self__, "is_private", is_private)
        pulumi.set(__self__, "registry_account", registry_account)
        pulumi.set(__self__, "registry_server", registry_server)
        if custom_images is not None:
            pulumi.set(__self__, "custom_images", custom_images)
        if infra_id is not None:
            pulumi.set(__self__, "infra_id", infra_id)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if is_override_allowed is not None:
            pulumi.set(__self__, "is_override_allowed", is_override_allowed)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if secret_name is not None:
            pulumi.set(__self__, "secret_name", secret_name)
        if use_custom_images is not None:
            pulumi.set(__self__, "use_custom_images", use_custom_images)

    @_builtins.property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether the registry is private
        """
        return pulumi.get(self, "is_private")

    @is_private.setter
    def is_private(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "is_private", value)

    @_builtins.property
    @pulumi.getter(name="registryAccount")
    def registry_account(self) -> pulumi.Input[_builtins.str]:
        """
        The registry account name
        """
        return pulumi.get(self, "registry_account")

    @registry_account.setter
    def registry_account(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "registry_account", value)

    @_builtins.property
    @pulumi.getter(name="registryServer")
    def registry_server(self) -> pulumi.Input[_builtins.str]:
        """
        The registry server URL
        """
        return pulumi.get(self, "registry_server")

    @registry_server.setter
    def registry_server(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "registry_server", value)

    @_builtins.property
    @pulumi.getter(name="customImages")
    def custom_images(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]]]:
        """
        Custom images configuration
        """
        return pulumi.get(self, "custom_images")

    @custom_images.setter
    def custom_images(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]]]):
        pulumi.set(self, "custom_images", value)

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The infrastructure ID to set up the image registry
        """
        return pulumi.get(self, "infra_id")

    @infra_id.setter
    def infra_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "infra_id", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this is the default registry
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter(name="isOverrideAllowed")
    def is_override_allowed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether override is allowed for this registry
        """
        return pulumi.get(self, "is_override_allowed")

    @is_override_allowed.setter
    def is_override_allowed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_override_allowed", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID of the image registry
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the image registry
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the secret for authentication
        """
        return pulumi.get(self, "secret_name")

    @secret_name.setter
    def secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_name", value)

    @_builtins.property
    @pulumi.getter(name="useCustomImages")
    def use_custom_images(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to use custom images
        """
        return pulumi.get(self, "use_custom_images")

    @use_custom_images.setter
    def use_custom_images(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_custom_images", value)


@pulumi.input_type
class _ImageRegistryState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_images: Optional[pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_override_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_private: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_account: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_server: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 use_custom_images: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ImageRegistry resources.
        :param pulumi.Input[_builtins.str] created_at: Creation timestamp
        :param pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]] custom_images: Custom images configuration
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to set up the image registry
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default registry
        :param pulumi.Input[_builtins.bool] is_override_allowed: Whether override is allowed for this registry
        :param pulumi.Input[_builtins.bool] is_private: Whether the registry is private
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the image registry
        :param pulumi.Input[_builtins.str] project_id: The project ID of the image registry
        :param pulumi.Input[_builtins.str] registry_account: The registry account name
        :param pulumi.Input[_builtins.str] registry_server: The registry server URL
        :param pulumi.Input[_builtins.str] secret_name: The name of the secret for authentication
        :param pulumi.Input[_builtins.str] updated_at: Last update timestamp
        :param pulumi.Input[_builtins.bool] use_custom_images: Whether to use custom images
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_images is not None:
            pulumi.set(__self__, "custom_images", custom_images)
        if infra_id is not None:
            pulumi.set(__self__, "infra_id", infra_id)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if is_override_allowed is not None:
            pulumi.set(__self__, "is_override_allowed", is_override_allowed)
        if is_private is not None:
            pulumi.set(__self__, "is_private", is_private)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if registry_account is not None:
            pulumi.set(__self__, "registry_account", registry_account)
        if registry_server is not None:
            pulumi.set(__self__, "registry_server", registry_server)
        if secret_name is not None:
            pulumi.set(__self__, "secret_name", secret_name)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if use_custom_images is not None:
            pulumi.set(__self__, "use_custom_images", use_custom_images)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="customImages")
    def custom_images(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]]]:
        """
        Custom images configuration
        """
        return pulumi.get(self, "custom_images")

    @custom_images.setter
    def custom_images(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageRegistryCustomImageArgs']]]]):
        pulumi.set(self, "custom_images", value)

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The infrastructure ID to set up the image registry
        """
        return pulumi.get(self, "infra_id")

    @infra_id.setter
    def infra_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "infra_id", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this is the default registry
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter(name="isOverrideAllowed")
    def is_override_allowed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether override is allowed for this registry
        """
        return pulumi.get(self, "is_override_allowed")

    @is_override_allowed.setter
    def is_override_allowed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_override_allowed", value)

    @_builtins.property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the registry is private
        """
        return pulumi.get(self, "is_private")

    @is_private.setter
    def is_private(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_private", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID of the image registry
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the image registry
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="registryAccount")
    def registry_account(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The registry account name
        """
        return pulumi.get(self, "registry_account")

    @registry_account.setter
    def registry_account(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_account", value)

    @_builtins.property
    @pulumi.getter(name="registryServer")
    def registry_server(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The registry server URL
        """
        return pulumi.get(self, "registry_server")

    @registry_server.setter
    def registry_server(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_server", value)

    @_builtins.property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the secret for authentication
        """
        return pulumi.get(self, "secret_name")

    @secret_name.setter
    def secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_name", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last update timestamp
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="useCustomImages")
    def use_custom_images(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to use custom images
        """
        return pulumi.get(self, "use_custom_images")

    @use_custom_images.setter
    def use_custom_images(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_custom_images", value)


@pulumi.type_token("harness:chaos/imageRegistry:ImageRegistry")
class ImageRegistry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_images: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageRegistryCustomImageArgs', 'ImageRegistryCustomImageArgsDict']]]]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_override_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_private: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_account: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_server: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 use_custom_images: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Resource for managing a Harness Chaos Image Registry

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.chaos.ImageRegistry("example",
            org_id="<org_id>",
            project_id="<project_id>",
            registry_server="<registry_server>",
            registry_account="<registry_account>",
            is_private=True,
            secret_name="<secret_name>",
            is_default=False,
            is_override_allowed=True,
            use_custom_images=True,
            custom_images=[{
                "log_watcher": "<log_watcher_image>",
                "ddcr": "<ddcr_image>",
                "ddcr_lib": "<ddcr_lib_image>",
                "ddcr_fault": "<ddcr_fault_image>",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ImageRegistryCustomImageArgs', 'ImageRegistryCustomImageArgsDict']]]] custom_images: Custom images configuration
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to set up the image registry
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default registry
        :param pulumi.Input[_builtins.bool] is_override_allowed: Whether override is allowed for this registry
        :param pulumi.Input[_builtins.bool] is_private: Whether the registry is private
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the image registry
        :param pulumi.Input[_builtins.str] project_id: The project ID of the image registry
        :param pulumi.Input[_builtins.str] registry_account: The registry account name
        :param pulumi.Input[_builtins.str] registry_server: The registry server URL
        :param pulumi.Input[_builtins.str] secret_name: The name of the secret for authentication
        :param pulumi.Input[_builtins.bool] use_custom_images: Whether to use custom images
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ImageRegistryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness Chaos Image Registry

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.chaos.ImageRegistry("example",
            org_id="<org_id>",
            project_id="<project_id>",
            registry_server="<registry_server>",
            registry_account="<registry_account>",
            is_private=True,
            secret_name="<secret_name>",
            is_default=False,
            is_override_allowed=True,
            use_custom_images=True,
            custom_images=[{
                "log_watcher": "<log_watcher_image>",
                "ddcr": "<ddcr_image>",
                "ddcr_lib": "<ddcr_lib_image>",
                "ddcr_fault": "<ddcr_fault_image>",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param ImageRegistryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ImageRegistryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_images: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageRegistryCustomImageArgs', 'ImageRegistryCustomImageArgsDict']]]]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_override_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_private: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_account: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_server: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 use_custom_images: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ImageRegistryArgs.__new__(ImageRegistryArgs)

            __props__.__dict__["custom_images"] = custom_images
            __props__.__dict__["infra_id"] = infra_id
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["is_override_allowed"] = is_override_allowed
            if is_private is None and not opts.urn:
                raise TypeError("Missing required property 'is_private'")
            __props__.__dict__["is_private"] = is_private
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if registry_account is None and not opts.urn:
                raise TypeError("Missing required property 'registry_account'")
            __props__.__dict__["registry_account"] = registry_account
            if registry_server is None and not opts.urn:
                raise TypeError("Missing required property 'registry_server'")
            __props__.__dict__["registry_server"] = registry_server
            __props__.__dict__["secret_name"] = secret_name
            __props__.__dict__["use_custom_images"] = use_custom_images
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(ImageRegistry, __self__).__init__(
            'harness:chaos/imageRegistry:ImageRegistry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            custom_images: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageRegistryCustomImageArgs', 'ImageRegistryCustomImageArgsDict']]]]] = None,
            infra_id: Optional[pulumi.Input[_builtins.str]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            is_override_allowed: Optional[pulumi.Input[_builtins.bool]] = None,
            is_private: Optional[pulumi.Input[_builtins.bool]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            registry_account: Optional[pulumi.Input[_builtins.str]] = None,
            registry_server: Optional[pulumi.Input[_builtins.str]] = None,
            secret_name: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            use_custom_images: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ImageRegistry':
        """
        Get an existing ImageRegistry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Creation timestamp
        :param pulumi.Input[Sequence[pulumi.Input[Union['ImageRegistryCustomImageArgs', 'ImageRegistryCustomImageArgsDict']]]] custom_images: Custom images configuration
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to set up the image registry
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default registry
        :param pulumi.Input[_builtins.bool] is_override_allowed: Whether override is allowed for this registry
        :param pulumi.Input[_builtins.bool] is_private: Whether the registry is private
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the image registry
        :param pulumi.Input[_builtins.str] project_id: The project ID of the image registry
        :param pulumi.Input[_builtins.str] registry_account: The registry account name
        :param pulumi.Input[_builtins.str] registry_server: The registry server URL
        :param pulumi.Input[_builtins.str] secret_name: The name of the secret for authentication
        :param pulumi.Input[_builtins.str] updated_at: Last update timestamp
        :param pulumi.Input[_builtins.bool] use_custom_images: Whether to use custom images
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ImageRegistryState.__new__(_ImageRegistryState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_images"] = custom_images
        __props__.__dict__["infra_id"] = infra_id
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["is_override_allowed"] = is_override_allowed
        __props__.__dict__["is_private"] = is_private
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["registry_account"] = registry_account
        __props__.__dict__["registry_server"] = registry_server
        __props__.__dict__["secret_name"] = secret_name
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["use_custom_images"] = use_custom_images
        return ImageRegistry(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="customImages")
    def custom_images(self) -> pulumi.Output[Sequence['outputs.ImageRegistryCustomImage']]:
        """
        Custom images configuration
        """
        return pulumi.get(self, "custom_images")

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The infrastructure ID to set up the image registry
        """
        return pulumi.get(self, "infra_id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether this is the default registry
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter(name="isOverrideAllowed")
    def is_override_allowed(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether override is allowed for this registry
        """
        return pulumi.get(self, "is_override_allowed")

    @_builtins.property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the registry is private
        """
        return pulumi.get(self, "is_private")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The organization ID of the image registry
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The project ID of the image registry
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="registryAccount")
    def registry_account(self) -> pulumi.Output[_builtins.str]:
        """
        The registry account name
        """
        return pulumi.get(self, "registry_account")

    @_builtins.property
    @pulumi.getter(name="registryServer")
    def registry_server(self) -> pulumi.Output[_builtins.str]:
        """
        The registry server URL
        """
        return pulumi.get(self, "registry_server")

    @_builtins.property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the secret for authentication
        """
        return pulumi.get(self, "secret_name")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Last update timestamp
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="useCustomImages")
    def use_custom_images(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to use custom images
        """
        return pulumi.get(self, "use_custom_images")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetTemplateResult',
    'AwaitableGetTemplateResult',
    'get_template',
    'get_template_output',
]

@pulumi.output_type
class GetTemplateResult:
    """
    A collection of values returned by getTemplate.
    """
    def __init__(__self__, branch_name=None, child_type=None, connector_ref=None, description=None, git_details=None, id=None, identifier=None, is_stable=None, name=None, org_id=None, project_id=None, scope=None, store_type=None, tags=None, template_yaml=None, version=None):
        if branch_name and not isinstance(branch_name, str):
            raise TypeError("Expected argument 'branch_name' to be a str")
        pulumi.set(__self__, "branch_name", branch_name)
        if child_type and not isinstance(child_type, str):
            raise TypeError("Expected argument 'child_type' to be a str")
        pulumi.set(__self__, "child_type", child_type)
        if connector_ref and not isinstance(connector_ref, str):
            raise TypeError("Expected argument 'connector_ref' to be a str")
        pulumi.set(__self__, "connector_ref", connector_ref)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if git_details and not isinstance(git_details, dict):
            raise TypeError("Expected argument 'git_details' to be a dict")
        pulumi.set(__self__, "git_details", git_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if is_stable and not isinstance(is_stable, bool):
            raise TypeError("Expected argument 'is_stable' to be a bool")
        pulumi.set(__self__, "is_stable", is_stable)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)
        if store_type and not isinstance(store_type, str):
            raise TypeError("Expected argument 'store_type' to be a str")
        pulumi.set(__self__, "store_type", store_type)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if template_yaml and not isinstance(template_yaml, str):
            raise TypeError("Expected argument 'template_yaml' to be a str")
        pulumi.set(__self__, "template_yaml", template_yaml)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="branchName")
    def branch_name(self) -> Optional[_builtins.str]:
        """
        Version Label for Template.
        """
        return pulumi.get(self, "branch_name")

    @_builtins.property
    @pulumi.getter(name="childType")
    def child_type(self) -> Optional[_builtins.str]:
        """
        Defines child template type.
        """
        return pulumi.get(self, "child_type")

    @_builtins.property
    @pulumi.getter(name="connectorRef")
    def connector_ref(self) -> _builtins.str:
        """
        Identifier of the Harness Connector used for CRUD operations on the Entity.
        """
        return pulumi.get(self, "connector_ref")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional['outputs.GetTemplateGitDetailsResult']:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="isStable")
    def is_stable(self) -> Optional[_builtins.bool]:
        """
        True if given version for template to be set as stable.
        """
        return pulumi.get(self, "is_stable")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def scope(self) -> Optional[_builtins.str]:
        """
        Scope of template.
        """
        return pulumi.get(self, "scope")

    @_builtins.property
    @pulumi.getter(name="storeType")
    def store_type(self) -> _builtins.str:
        """
        Specifies whether the Entity is to be stored in Git or not. Possible values: INLINE, REMOTE.
        """
        return pulumi.get(self, "store_type")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="templateYaml")
    def template_yaml(self) -> _builtins.str:
        """
        Yaml for creating new Template.
        """
        return pulumi.get(self, "template_yaml")

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[_builtins.str]:
        """
        Version Label for Template.
        """
        return pulumi.get(self, "version")


class AwaitableGetTemplateResult(GetTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTemplateResult(
            branch_name=self.branch_name,
            child_type=self.child_type,
            connector_ref=self.connector_ref,
            description=self.description,
            git_details=self.git_details,
            id=self.id,
            identifier=self.identifier,
            is_stable=self.is_stable,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            scope=self.scope,
            store_type=self.store_type,
            tags=self.tags,
            template_yaml=self.template_yaml,
            version=self.version)


def get_template(branch_name: Optional[_builtins.str] = None,
                 child_type: Optional[_builtins.str] = None,
                 git_details: Optional[Union['GetTemplateGitDetailsArgs', 'GetTemplateGitDetailsArgsDict']] = None,
                 identifier: Optional[_builtins.str] = None,
                 is_stable: Optional[_builtins.bool] = None,
                 name: Optional[_builtins.str] = None,
                 org_id: Optional[_builtins.str] = None,
                 project_id: Optional[_builtins.str] = None,
                 scope: Optional[_builtins.str] = None,
                 version: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTemplateResult:
    """
    Data source for retrieving a Harness pipeline.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    #For account level template
    example = harness.platform.get_template(identifier="identifier",
        version="version")
    #For org level template
    example1 = harness.platform.get_template(identifier="identifier",
        version="version",
        org_id="org_id")
    #For project level template
    example2 = harness.platform.get_template(identifier="identifier",
        version="version",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str branch_name: Version Label for Template.
    :param _builtins.str child_type: Defines child template type.
    :param Union['GetTemplateGitDetailsArgs', 'GetTemplateGitDetailsArgsDict'] git_details: Contains parameters related to creating an Entity for Git Experience.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.bool is_stable: True if given version for template to be set as stable.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str scope: Scope of template.
    :param _builtins.str version: Version Label for Template.
    """
    __args__ = dict()
    __args__['branchName'] = branch_name
    __args__['childType'] = child_type
    __args__['gitDetails'] = git_details
    __args__['identifier'] = identifier
    __args__['isStable'] = is_stable
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['scope'] = scope
    __args__['version'] = version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getTemplate:getTemplate', __args__, opts=opts, typ=GetTemplateResult).value

    return AwaitableGetTemplateResult(
        branch_name=pulumi.get(__ret__, 'branch_name'),
        child_type=pulumi.get(__ret__, 'child_type'),
        connector_ref=pulumi.get(__ret__, 'connector_ref'),
        description=pulumi.get(__ret__, 'description'),
        git_details=pulumi.get(__ret__, 'git_details'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        is_stable=pulumi.get(__ret__, 'is_stable'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        scope=pulumi.get(__ret__, 'scope'),
        store_type=pulumi.get(__ret__, 'store_type'),
        tags=pulumi.get(__ret__, 'tags'),
        template_yaml=pulumi.get(__ret__, 'template_yaml'),
        version=pulumi.get(__ret__, 'version'))
def get_template_output(branch_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        child_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        git_details: Optional[pulumi.Input[Optional[Union['GetTemplateGitDetailsArgs', 'GetTemplateGitDetailsArgsDict']]]] = None,
                        identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        is_stable: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        scope: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        version: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTemplateResult]:
    """
    Data source for retrieving a Harness pipeline.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    #For account level template
    example = harness.platform.get_template(identifier="identifier",
        version="version")
    #For org level template
    example1 = harness.platform.get_template(identifier="identifier",
        version="version",
        org_id="org_id")
    #For project level template
    example2 = harness.platform.get_template(identifier="identifier",
        version="version",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str branch_name: Version Label for Template.
    :param _builtins.str child_type: Defines child template type.
    :param Union['GetTemplateGitDetailsArgs', 'GetTemplateGitDetailsArgsDict'] git_details: Contains parameters related to creating an Entity for Git Experience.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.bool is_stable: True if given version for template to be set as stable.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str scope: Scope of template.
    :param _builtins.str version: Version Label for Template.
    """
    __args__ = dict()
    __args__['branchName'] = branch_name
    __args__['childType'] = child_type
    __args__['gitDetails'] = git_details
    __args__['identifier'] = identifier
    __args__['isStable'] = is_stable
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['scope'] = scope
    __args__['version'] = version
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getTemplate:getTemplate', __args__, opts=opts, typ=GetTemplateResult)
    return __ret__.apply(lambda __response__: GetTemplateResult(
        branch_name=pulumi.get(__response__, 'branch_name'),
        child_type=pulumi.get(__response__, 'child_type'),
        connector_ref=pulumi.get(__response__, 'connector_ref'),
        description=pulumi.get(__response__, 'description'),
        git_details=pulumi.get(__response__, 'git_details'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        is_stable=pulumi.get(__response__, 'is_stable'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        scope=pulumi.get(__response__, 'scope'),
        store_type=pulumi.get(__response__, 'store_type'),
        tags=pulumi.get(__response__, 'tags'),
        template_yaml=pulumi.get(__response__, 'template_yaml'),
        version=pulumi.get(__response__, 'version')))
